..
      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

F5 Networks Provider Driver for OpenStack Octavia by SAP SE
==============================================================

F5 Networks Provider Driver for OpenStack Octavia provided by SAP SE.

Default provider name: **f5**

The driver source: https://github.com/sapcc/octavia-f5-provider-driver

Where to report issues with the driver: Contact SAP SE
